[![PyPI version](https://badge.fury.io/py/pytest-embrace.svg)](https://badge.fury.io/py/pytest-embrace) [![PyPI pyversions](https://img.shields.io/pypi/pyversions/pytest-embrace.svg)](https://pypi.python.org/pypi/pytest-embrace/) ![CI](https://github.com/ainsleymcgrath/pytest-embrace/actions/workflows/ci.yml/badge.svg)

![logotype](https://raw.githubusercontent.com/ainsleymcgrath/pytest-embrace/master/docs/logotype.svg)

The `pytest-embrace` plugin enables judicious, repeatable, lucid unit testing using.

Check out [the docs](https://ainsleymcgrath.github.io/pytest-embrace/) for more.
